summaryrefslogtreecommitdiffstats
path: root/src/H5Vprivate.h
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>2003-12-06 20:38:31 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>2003-12-06 20:38:31 (GMT)
commit31431be37492b0446c048401bcb9512ae23ef8f4 (patch)
tree9928afd828704483be974f8e2cd8238bbc576869 /src/H5Vprivate.h
parent1b1e1ebbbd5b4d18c5f413e79b58f7f7e782519f (diff)
downloadhdf5-31431be37492b0446c048401bcb9512ae23ef8f4.zip
hdf5-31431be37492b0446c048401bcb9512ae23ef8f4.tar.gz
hdf5-31431be37492b0446c048401bcb9512ae23ef8f4.tar.bz2
[svn-r7917] Purpose:
Code cleanup Description: Clean up compiler warnings, especially the 'FUNC' variable not used which comes out in production mode. Solution: Had to add a new FUNC_ENTER_NOAPI_NOINIT_NOFUNC macro for those non-API functions which don't need the 'FUNC' variable defined. (This will be _so_ much easier when C99 is standard on all our supposed platforms, since it has a __FUNC__ macro... ) Platforms tested: FreeBSD 4.9 (sleipnir) too minor for h5committest (although there were lots of files changed, the change was minor in each one)
Diffstat (limited to 'src/H5Vprivate.h')
-rw-r--r--src/H5Vprivate.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/H5Vprivate.h b/src/H5Vprivate.h
index 607087c..998b12b 100644
--- a/src/H5Vprivate.h
+++ b/src/H5Vprivate.h
@@ -114,8 +114,8 @@ H5V_vector_reduce_product(unsigned n, const hsize_t *v)
{
hsize_t ret_value = 1;
- /* Use FUNC_ENTER_NOINIT here to avoid performance issues */
- FUNC_ENTER_NOINIT(H5V_vector_reduce_product)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5V_vector_reduce_product)
if (n && !v) HGOTO_DONE(0)
while (n--) ret_value *= *v++;
@@ -146,8 +146,8 @@ H5V_vector_zerop_u(int n, const hsize_t *v)
{
htri_t ret_value=TRUE; /* Return value */
- /* Use FUNC_ENTER_NOINIT here to avoid performance issues */
- FUNC_ENTER_NOINIT(H5V_vector_zerop_u)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5V_vector_zerop_u)
if (!v)
HGOTO_DONE(TRUE)
@@ -181,8 +181,8 @@ H5V_vector_zerop_s(int n, const hssize_t *v)
{
htri_t ret_value=TRUE; /* Return value */
- /* Use FUNC_ENTER_NOINIT here to avoid performance issues */
- FUNC_ENTER_NOINIT(H5V_vector_zerop_s)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5V_vector_zerop_s)
if (!v)
HGOTO_DONE(TRUE)
@@ -218,8 +218,8 @@ H5V_vector_cmp_u (int n, const hsize_t *v1, const hsize_t *v2)
{
int ret_value=0; /* Return value */
- /* Use FUNC_ENTER_NOINIT here to avoid performance issues */
- FUNC_ENTER_NOINIT(H5V_vector_cmp_u)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5V_vector_cmp_u)
if (v1 == v2) HGOTO_DONE(0)
while (n--) {
@@ -258,8 +258,8 @@ H5V_vector_cmp_s (unsigned n, const hssize_t *v1, const hssize_t *v2)
{
int ret_value=0; /* Return value */
- /* Use FUNC_ENTER_NOINIT here to avoid performance issues */
- FUNC_ENTER_NOINIT(H5V_vector_cmp_s)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5V_vector_cmp_s)
if (v1 == v2) HGOTO_DONE(0)
while (n--) {